@@ -15,9 +15,6 @@
 
     Contact: code@inmanta.com
 """
-import warnings
-
-import toml
 
 """
 About the use of @parametrize_any and @slowtest:
@@ -58,10 +55,12 @@ The deactive_venv autouse fixture cleans up all venv activation and resets inman
 environment.
 """
 
+
 import asyncio
 import concurrent
 import csv
 import datetime
+import importlib.util
 import json
 import logging
 import os
@@ -79,9 +78,9 @@ import time
 import traceback
 import uuid
 import venv
-from collections import abc
 from configparser import ConfigParser
-from typing import AsyncIterator, Awaitable, Callable, Dict, Iterator, List, Optional, Tuple, Union
+from types import ModuleType
+from typing import AsyncIterator, Awaitable, Callable, Dict, Iterator, List, Optional, Tuple
 
 import asyncpg
 import pkg_resources
@@ -108,20 +107,18 @@ from inmanta.agent import handler
 from inmanta.agent.agent import Agent
 from inmanta.ast import CompilerException
 from inmanta.data.schema import SCHEMA_VERSION_TABLE
-from inmanta.env import LocalPackagePath, VirtualEnv, mock_process_env
-from inmanta.export import ResourceDict, cfg_env, unknown_parameters
+from inmanta.env import LocalPackagePath
+from inmanta.export import cfg_env, unknown_parameters
 from inmanta.module import InmantaModuleRequirement, InstallMode, Project, RelationPrecedenceRule
-from inmanta.moduletool import IsolatedEnvBuilderCached, ModuleTool, V2ModuleBuilder
+from inmanta.moduletool import ModuleTool
 from inmanta.parser.plyInmantaParser import cache_manager
 from inmanta.protocol import VersionMatch
 from inmanta.server import SLICE_AGENT_MANAGER, SLICE_COMPILER
 from inmanta.server.bootloader import InmantaBootloader
-from inmanta.server.protocol import Server, SliceStartupException
+from inmanta.server.protocol import SliceStartupException
 from inmanta.server.services.compilerservice import CompilerService, CompileRun
 from inmanta.types import JsonType
-from inmanta.warnings import WarningsManager
 from libpip2pi.commands import dir2pi
-from packaging.version import Version
 
 # Import test modules differently when conftest is put into the inmanta_tests packages
 PYTEST_PLUGIN_MODE: bool = __file__ and os.path.dirname(__file__).split("/")[-1] == "inmanta_tests"
@@ -134,7 +131,7 @@ else:
 
 logger = logging.getLogger(__name__)
 
-TABLES_TO_KEEP = [x.table_name() for x in data._classes] + ["resourceaction_resource"]  # Join table
+TABLES_TO_KEEP = [x.table_name() for x in data._classes]
 
 # Save the cwd as early as possible to prevent that it gets overridden by another fixture
 # before it's saved.
@@ -193,7 +190,7 @@ def pytest_generate_tests(metafunc: "pytest.Metafunc") -> None:
 
 def pytest_runtest_setup(item: "pytest.Item"):
     """
-    When in fast mode, skip test marked as slow and db_migration tests that are older than 30 days.
+    When in fast mode, skip test marked as slow
     """
     is_fast = item.config.getoption("fast")
     if not is_fast:
@@ -201,20 +198,6 @@ def pytest_runtest_setup(item: "pytest.Item"):
     if any(True for mark in item.iter_markers(name="slowtest")):
         pytest.skip("Skipping slow tests")
 
-    file_name: str = item.location[0]
-    if file_name.startswith("tests/db/migration_tests"):
-        match: Optional[re.Match] = re.fullmatch("tests/db/migration_tests/test_v[0-9]{9}_to_v([0-9]{8})[0-9].py", file_name)
-        if not match:
-            pytest.fail(
-                "The name of the test file might be incorrect: Should be test_v<old_version>_to_v<new_version>.py or the test "
-                "should have the @slowtest annotation"
-            )
-        timestamp: str = match.group(1)
-        test_creation_date: datetime.datetime = datetime.datetime(int(timestamp[0:4]), int(timestamp[4:6]), int(timestamp[6:8]))
-        elapsed_days: int = (datetime.datetime.today() - test_creation_date).days
-        if elapsed_days > 30:
-            pytest.skip("Skipping old migration test")
-
 
 @pytest.fixture(scope="session")
 def postgres_db(request: pytest.FixtureRequest):
@@ -232,19 +215,6 @@ def postgres_db(request: pytest.FixtureRequest):
     yield request.getfixturevalue(fixture)
 
 
-@pytest.fixture
-async def postgres_db_debug(postgres_db, database_name) -> abc.AsyncIterator[None]:
-    """
-    Fixture meant for debugging through manual interaction with the database. Run pytest with `-s/--capture=no`.
-    """
-    yield
-    print(
-        "Connection to DB will be kept alive for one hour. Connect with"
-        f" `psql --host localhost --port {postgres_db.port} {database_name} {postgres_db.user}`"
-    )
-    await asyncio.sleep(3600)
-
-
 @pytest.fixture
 def ensure_running_postgres_db_post(postgres_db):
     yield
@@ -466,13 +436,11 @@ def get_custom_postgresql_types(postgresql_client) -> Callable[[], Awaitable[Lis
     return f
 
 
-@pytest.fixture(scope="function")
+@pytest.fixture(scope="function", autouse=True)
 def deactive_venv():
     old_os_path = os.environ.get("PATH", "")
     old_prefix = sys.prefix
     old_path = list(sys.path)
-    old_meta_path = sys.meta_path.copy()
-    old_path_hooks = sys.path_hooks.copy()
     old_pythonpath = os.environ.get("PYTHONPATH", None)
     old_os_venv: Optional[str] = os.environ.get("VIRTUAL_ENV", None)
     old_process_env: str = env.process_env.python_path
@@ -486,13 +454,6 @@ def deactive_venv():
     os.environ["PATH"] = old_os_path
     sys.prefix = old_prefix
     sys.path = old_path
-    # reset sys.meta_path because it might contain finders for editable installs, make sure to keep the same object
-    sys.meta_path.clear()
-    sys.meta_path.extend(old_meta_path)
-    sys.path_hooks.clear()
-    sys.path_hooks.extend(old_path_hooks)
-    # Clear cache for sys.path_hooks
-    sys.path_importer_cache.clear()
     pkg_resources.working_set = old_working_set
     # Restore PYTHONPATH
     if old_pythonpath is not None:
@@ -514,28 +475,17 @@ def reset_metrics():
 
 
 @pytest.fixture(scope="function", autouse=True)
-async def clean_reset(create_db, clean_db, deactive_venv):
+async def clean_reset(create_db, clean_db):
     reset_all_objects()
     config.Config._reset()
     methods = inmanta.protocol.common.MethodProperties.methods.copy()
     loader.unload_inmanta_plugins()
-    default_settings = dict(data.Environment._settings)
     yield
     inmanta.protocol.common.MethodProperties.methods = methods
     config.Config._reset()
     reset_all_objects()
     loader.unload_inmanta_plugins()
     cache_manager.detach_from_project()
-    data.Environment._settings = default_settings
-
-
-@pytest.fixture(scope="session", autouse=True)
-def clean_reset_session():
-    """
-    Execute cleanup tasks that should only run at the end of the test suite.
-    """
-    yield
-    IsolatedEnvBuilderCached.get_instance().destroy()
 
 
 def reset_all_objects():
@@ -548,13 +498,6 @@ def reset_all_objects():
     Project._project = None
     unknown_parameters.clear()
     InmantaBootloader.AVAILABLE_EXTENSIONS = None
-    V2ModuleBuilder.DISABLE_ISOLATED_ENV_BUILDER_CACHE = False
-    compiler.Finalizers.reset_finalizers()
-
-
-@pytest.fixture()
-def disable_isolated_env_builder_cache() -> None:
-    V2ModuleBuilder.DISABLE_ISOLATED_ENV_BUILDER_CACHE = True
 
 
 @pytest.fixture(scope="function", autouse=True)
@@ -727,33 +670,34 @@ def log_state_tcp_ports(request, log_file):
 async def server_config(event_loop, inmanta_config, postgres_db, database_name, clean_reset, unused_tcp_port_factory):
     reset_metrics()
 
-    with tempfile.TemporaryDirectory() as state_dir:
-        port = str(unused_tcp_port_factory())
+    state_dir = tempfile.mkdtemp()
 
-        config.Config.set("database", "name", database_name)
-        config.Config.set("database", "host", "localhost")
-        config.Config.set("database", "port", str(postgres_db.port))
-        config.Config.set("database", "username", postgres_db.user)
-        config.Config.set("database", "password", postgres_db.password)
-        config.Config.set("database", "connection_timeout", str(3))
-        config.Config.set("config", "state-dir", state_dir)
-        config.Config.set("config", "log-dir", os.path.join(state_dir, "logs"))
-        config.Config.set("agent_rest_transport", "port", port)
-        config.Config.set("compiler_rest_transport", "port", port)
-        config.Config.set("client_rest_transport", "port", port)
-        config.Config.set("cmdline_rest_transport", "port", port)
-        config.Config.set("server", "bind-port", port)
-        config.Config.set("server", "bind-address", "127.0.0.1")
-        config.Config.set("server", "agent-process-purge-interval", "0")
-        config.Config.set("config", "executable", os.path.abspath(inmanta.app.__file__))
-        config.Config.set("server", "agent-timeout", "2")
-        config.Config.set("server", "auto-recompile-wait", "0")
-        config.Config.set("agent", "agent-repair-interval", "0")
-        yield config
+    port = str(unused_tcp_port_factory())
+
+    config.Config.set("database", "name", database_name)
+    config.Config.set("database", "host", "localhost")
+    config.Config.set("database", "port", str(postgres_db.port))
+    config.Config.set("database", "username", postgres_db.user)
+    config.Config.set("database", "password", postgres_db.password)
+    config.Config.set("database", "connection_timeout", str(3))
+    config.Config.set("config", "state-dir", state_dir)
+    config.Config.set("config", "log-dir", os.path.join(state_dir, "logs"))
+    config.Config.set("agent_rest_transport", "port", port)
+    config.Config.set("compiler_rest_transport", "port", port)
+    config.Config.set("client_rest_transport", "port", port)
+    config.Config.set("cmdline_rest_transport", "port", port)
+    config.Config.set("server", "bind-port", port)
+    config.Config.set("server", "bind-address", "127.0.0.1")
+    config.Config.set("server", "agent-process-purge-interval", "0")
+    config.Config.set("config", "executable", os.path.abspath(inmanta.app.__file__))
+    config.Config.set("server", "agent-timeout", "2")
+    config.Config.set("agent", "agent-repair-interval", "0")
+    yield config
+    shutil.rmtree(state_dir)
 
 
 @pytest.fixture(scope="function")
-async def server(server_pre_start) -> abc.AsyncIterator[Server]:
+async def server(server_pre_start):
     """
     :param event_loop: explicitly include event_loop to make sure event loop started before and closed after this fixture.
     May not be required
@@ -795,74 +739,76 @@ async def server_multi(
     :param event_loop: explicitly include event_loop to make sure event loop started before and closed after this fixture.
     May not be required
     """
-    with tempfile.TemporaryDirectory() as state_dir:
-        ssl, auth, ca = request.param
+    state_dir = tempfile.mkdtemp()
 
-        path = os.path.join(os.path.dirname(os.path.abspath(__file__)), "data")
+    ssl, auth, ca = request.param
 
-        if auth:
-            config.Config.set("server", "auth", "true")
+    path = os.path.join(os.path.dirname(os.path.abspath(__file__)), "data")
 
-        for x, ct in [
-            ("server", None),
-            ("agent_rest_transport", ["agent"]),
-            ("compiler_rest_transport", ["compiler"]),
-            ("client_rest_transport", ["api", "compiler"]),
-            ("cmdline_rest_transport", ["api"]),
-        ]:
-            if ssl and not ca:
-                config.Config.set(x, "ssl_cert_file", os.path.join(path, "server.crt"))
-                config.Config.set(x, "ssl_key_file", os.path.join(path, "server.open.key"))
-                config.Config.set(x, "ssl_ca_cert_file", os.path.join(path, "server.crt"))
-                config.Config.set(x, "ssl", "True")
-            if ssl and ca:
-                capath = os.path.join(path, "ca", "enduser-certs")
+    if auth:
+        config.Config.set("server", "auth", "true")
 
-                config.Config.set(x, "ssl_cert_file", os.path.join(capath, "server.crt"))
-                config.Config.set(x, "ssl_key_file", os.path.join(capath, "server.key.open"))
-                config.Config.set(x, "ssl_ca_cert_file", os.path.join(capath, "server.chain"))
-                config.Config.set(x, "ssl", "True")
-            if auth and ct is not None:
-                token = protocol.encode_token(ct)
-                config.Config.set(x, "token", token)
+    for x, ct in [
+        ("server", None),
+        ("agent_rest_transport", ["agent"]),
+        ("compiler_rest_transport", ["compiler"]),
+        ("client_rest_transport", ["api", "compiler"]),
+        ("cmdline_rest_transport", ["api"]),
+    ]:
+        if ssl and not ca:
+            config.Config.set(x, "ssl_cert_file", os.path.join(path, "server.crt"))
+            config.Config.set(x, "ssl_key_file", os.path.join(path, "server.open.key"))
+            config.Config.set(x, "ssl_ca_cert_file", os.path.join(path, "server.crt"))
+            config.Config.set(x, "ssl", "True")
+        if ssl and ca:
+            capath = os.path.join(path, "ca", "enduser-certs")
 
-        port = str(unused_tcp_port_factory())
-        config.Config.set("database", "name", database_name)
-        config.Config.set("database", "host", "localhost")
-        config.Config.set("database", "port", str(postgres_db.port))
-        config.Config.set("database", "username", postgres_db.user)
-        config.Config.set("database", "password", postgres_db.password)
-        config.Config.set("database", "connection_timeout", str(3))
-        config.Config.set("config", "state-dir", state_dir)
-        config.Config.set("config", "log-dir", os.path.join(state_dir, "logs"))
-        config.Config.set("agent_rest_transport", "port", port)
-        config.Config.set("compiler_rest_transport", "port", port)
-        config.Config.set("client_rest_transport", "port", port)
-        config.Config.set("cmdline_rest_transport", "port", port)
-        config.Config.set("server", "bind-port", port)
-        config.Config.set("server", "bind-address", "127.0.0.1")
-        config.Config.set("config", "executable", os.path.abspath(inmanta.app.__file__))
-        config.Config.set("server", "agent-timeout", "2")
-        config.Config.set("agent", "agent-repair-interval", "0")
-        config.Config.set("server", "auto-recompile-wait", "0")
+            config.Config.set(x, "ssl_cert_file", os.path.join(capath, "server.crt"))
+            config.Config.set(x, "ssl_key_file", os.path.join(capath, "server.key.open"))
+            config.Config.set(x, "ssl_ca_cert_file", os.path.join(capath, "server.chain"))
+            config.Config.set(x, "ssl", "True")
+        if auth and ct is not None:
+            token = protocol.encode_token(ct)
+            config.Config.set(x, "token", token)
 
-        ibl = InmantaBootloader()
+    port = str(unused_tcp_port_factory())
+    config.Config.set("database", "name", database_name)
+    config.Config.set("database", "host", "localhost")
+    config.Config.set("database", "port", str(postgres_db.port))
+    config.Config.set("database", "username", postgres_db.user)
+    config.Config.set("database", "password", postgres_db.password)
+    config.Config.set("database", "connection_timeout", str(3))
+    config.Config.set("config", "state-dir", state_dir)
+    config.Config.set("config", "log-dir", os.path.join(state_dir, "logs"))
+    config.Config.set("agent_rest_transport", "port", port)
+    config.Config.set("compiler_rest_transport", "port", port)
+    config.Config.set("client_rest_transport", "port", port)
+    config.Config.set("cmdline_rest_transport", "port", port)
+    config.Config.set("server", "bind-port", port)
+    config.Config.set("server", "bind-address", "127.0.0.1")
+    config.Config.set("config", "executable", os.path.abspath(inmanta.app.__file__))
+    config.Config.set("server", "agent-timeout", "2")
+    config.Config.set("agent", "agent-repair-interval", "0")
 
-        try:
-            await ibl.start()
-        except SliceStartupException as e:
-            port = config.Config.get("server", "bind-port")
-            output = subprocess.check_output(["ss", "-antp"])
-            output = output.decode("utf-8")
-            logger.debug(f"Port: {port}")
-            logger.debug(f"Port usage: \n {output}")
-            raise e
+    ibl = InmantaBootloader()
 
-        yield ibl.restserver
-        try:
-            await ibl.stop(timeout=15)
-        except concurrent.futures.TimeoutError:
-            logger.exception("Timeout during stop of the server in teardown")
+    try:
+        await ibl.start()
+    except SliceStartupException as e:
+        port = config.Config.get("server", "bind-port")
+        output = subprocess.check_output(["ss", "-antp"])
+        output = output.decode("utf-8")
+        logger.debug(f"Port: {port}")
+        logger.debug(f"Port usage: \n {output}")
+        raise e
+
+    yield ibl.restserver
+    try:
+        await ibl.stop(timeout=15)
+    except concurrent.futures.TimeoutError:
+        logger.exception("Timeout during stop of the server in teardown")
+
+    shutil.rmtree(state_dir)
 
 
 @pytest.fixture(scope="function")
@@ -890,12 +836,8 @@ def clienthelper(client, environment):
 
 @pytest.fixture(scope="function", autouse=True)
 def capture_warnings():
-    # Ensure that the test suite uses the same config for warnings as the default config used by the CLI tools.
     logging.captureWarnings(True)
-    cmd_parser = inmanta.app.cmd_parser()
-    WarningsManager.apply_config({"default": cmd_parser.get_default("warnings")})
     yield
-    warnings.resetwarnings()
     logging.captureWarnings(False)
 
 
@@ -922,6 +864,7 @@ async def create_environment(client, use_custom_env_settings: bool) -> str:
         await env_obj.set(data.AUTO_DEPLOY, False)
         await env_obj.set(data.PUSH_ON_AUTO_DEPLOY, False)
         await env_obj.set(data.AGENT_TRIGGER_METHOD_ON_AUTO_DEPLOY, const.AgentTriggerMethod.push_full_deploy)
+        await env_obj.set(data.RECOMPILE_BACKOFF, 0)
 
     return env_id
 
@@ -1003,49 +946,11 @@ async def off_main_thread(func):
     return await asyncio.get_event_loop().run_in_executor(None, func)
 
 
-class ReentrantVirtualEnv(VirtualEnv):
-    """
-    A virtual env that can be de-activated and re-activated
-
-    This allows faster reloading due to improved caching of the working set
-
-    This is intended for use in testcases to require a lot of venv switching
-    """
-
-    def __init__(self, env_path: str) -> None:
-        super(ReentrantVirtualEnv, self).__init__(env_path)
-        self.working_set = None
-
-    def deactivate(self):
-        if self._using_venv:
-            self._using_venv = False
-            self.working_set = pkg_resources.working_set
-
-    def use_virtual_env(self) -> None:
-        """
-        Activate the virtual environment.
-        """
-        if self._using_venv:
-            # We are in use, just ignore double activation
-            return
-
-        if not self.working_set:
-            # First run
-            super().use_virtual_env()
-        else:
-            # Later run
-            self._activate_that()
-            mock_process_env(python_path=self.python_path)
-            pkg_resources.working_set = self.working_set
-            self._using_venv = True
-
-
 class SnippetCompilationTest(KeepOnFail):
     def setUpClass(self):
         self.libs = tempfile.mkdtemp()
         self.repo = "https://github.com/inmanta/"
         self.env = tempfile.mkdtemp()
-        self.venv = ReentrantVirtualEnv(env_path=self.env)
         config.Config.load_config()
         self.keep_shared = False
         self.project = None
@@ -1062,11 +967,9 @@ class SnippetCompilationTest(KeepOnFail):
         self.modules_dir = module_dir
 
     def tear_down_func(self):
-        loader.unload_modules_for_path(self.env)
         if not self._keep:
             shutil.rmtree(self.project_dir)
         self.project = None
-        self.venv.deactivate()
 
     def keep(self):
         self._keep = True
@@ -1127,7 +1030,7 @@ class SnippetCompilationTest(KeepOnFail):
     ):
         loader.PluginModuleFinder.reset()
         self.project = Project(
-            self.project_dir, autostd=autostd, main_file=main_file, venv_path=self.venv, strict_deps_check=strict_deps_check
+            self.project_dir, autostd=autostd, main_file=main_file, venv_path=self.env, strict_deps_check=strict_deps_check
         )
         Project.set(self.project)
         self.project.use_virtual_env()
@@ -1223,7 +1126,7 @@ class SnippetCompilationTest(KeepOnFail):
         do_raise=True,
         partial_compile: bool = False,
         resource_sets_to_remove: Optional[List[str]] = None,
-    ) -> Union[tuple[int, ResourceDict], tuple[int, ResourceDict, dict[str, const.ResourceState]]]:
+    ):
         return self._do_export(
             deploy=False,
             include_status=include_status,
@@ -1243,7 +1146,7 @@ class SnippetCompilationTest(KeepOnFail):
         do_raise=True,
         partial_compile: bool = False,
         resource_sets_to_remove: Optional[List[str]] = None,
-    ) -> Union[tuple[int, ResourceDict], tuple[int, ResourceDict, dict[str, const.ResourceState]]]:
+    ):
         """
         helper function to allow actual export to be run on a different thread
         i.e. export.run must run off main thread to allow it to start a new ioloop for run_sync
@@ -1288,7 +1191,7 @@ class SnippetCompilationTest(KeepOnFail):
         do_raise=True,
         partial_compile: bool = False,
         resource_sets_to_remove: Optional[List[str]] = None,
-    ) -> Union[tuple[int, ResourceDict], tuple[int, ResourceDict, dict[str, const.ResourceState], Optional[dict[str, object]]]]:
+    ):
         return await off_main_thread(
             lambda: self._do_export(
                 deploy=True,
@@ -1349,8 +1252,6 @@ def snippetcompiler(
     """
     Yields a SnippetCompilationTest instance with shared libs directory and compiler venv.
     """
-    # Test with compiler cache enabled
-    compiler.config.feature_compiler_cache.set("True")
     snippetcompiler_global.setup_func(modules_dir)
     yield snippetcompiler_global
     snippetcompiler_global.tear_down_func()
@@ -1402,15 +1303,11 @@ class CLI(object):
 
 
 @pytest.fixture
-def cli(caplog):
-    # caplog will break this code when emitting any log line to cli
-    # due to mysterious interference when juggling with sys.stdout
-    # https://github.com/pytest-dev/pytest/issues/10553
-    with caplog.at_level(logging.FATAL):
-        # work around for https://github.com/pytest-dev/pytest-asyncio/issues/168
-        asyncio.set_event_loop_policy(AnyThreadEventLoopPolicy())
-        o = CLI()
-        yield o
+def cli():
+    # work around for https://github.com/pytest-dev/pytest-asyncio/issues/168
+    asyncio.set_event_loop_policy(AnyThreadEventLoopPolicy())
+    o = CLI()
+    yield o
 
 
 class AsyncCleaner(object):
@@ -1438,12 +1335,18 @@ class CompileRunnerMock(object):
         self.request = request
         self.version: Optional[int] = None
         self._make_compile_fail = make_compile_fail
-        self._make_pull_fail = False
         self._runner_queue = runner_queue
         self.block = False
 
     async def run(self, force_update: Optional[bool] = False) -> Tuple[bool, None]:
         now = datetime.datetime.now()
+        returncode = 1 if self._make_compile_fail else 0
+        report = data.Report(
+            compile=self.request.id, started=now, name="CompileRunnerMock", command="", completed=now, returncode=returncode
+        )
+        await report.insert()
+        self.version = int(time.time())
+        success = not self._make_compile_fail
 
         if self._runner_queue is not None:
             self._runner_queue.put(self)
@@ -1451,21 +1354,6 @@ class CompileRunnerMock(object):
             while self.block:
                 await asyncio.sleep(0.1)
 
-        returncode = 1 if self._make_compile_fail else 0
-        report = data.Report(
-            compile=self.request.id, started=now, name="CompileRunnerMock", command="", completed=now, returncode=returncode
-        )
-        await report.insert()
-
-        if self._make_pull_fail:
-            report = data.Report(
-                compile=self.request.id, started=now, name="Pulling updates", command="", completed=now, returncode=1
-            )
-            await report.insert()
-
-        self.version = int(time.time())
-        success = not self._make_compile_fail
-
         return success, None
 
 
@@ -1577,13 +1465,13 @@ def tmpvenv_active(
 
     yield tmpvenv
 
-    loader.unload_modules_for_path(site_packages)
+    unload_modules_for_path(site_packages)
     # Force refresh build's cache once more
     build.env._should_use_virtualenv.cache_clear()
 
 
 @pytest.fixture
-def tmpvenv_active_inherit(deactive_venv, tmpdir: py.path.local) -> Iterator[env.VirtualEnv]:
+def tmpvenv_active_inherit(tmpdir: py.path.local) -> Iterator[env.VirtualEnv]:
     """
     Creates and activates a venv similar to tmpvenv_active with the difference that this venv inherits from the previously
     active one.
@@ -1592,7 +1480,22 @@ def tmpvenv_active_inherit(deactive_venv, tmpdir: py.path.local) -> Iterator[env
     venv: env.VirtualEnv = env.VirtualEnv(str(venv_dir))
     venv.use_virtual_env()
     yield venv
-    loader.unload_modules_for_path(venv.site_packages_dir)
+    unload_modules_for_path(venv.site_packages_dir)
+
+
+def unload_modules_for_path(path: str) -> None:
+    """
+    Unload any modules that are loaded from a given path.
+    """
+
+    def module_in_prefix(module: ModuleType, prefix: str) -> bool:
+        file: Optional[str] = getattr(module, "__file__", None)
+        return file.startswith(prefix) if file is not None else False
+
+    loaded_modules: List[str] = [mod_name for mod_name, mod in sys.modules.items() if module_in_prefix(mod, path)]
+    for mod_name in loaded_modules:
+        del sys.modules[mod_name]
+    importlib.invalidate_caches()
 
 
 @pytest.fixture(scope="session")
@@ -1669,39 +1572,6 @@ async def migrate_db_from(
     await bootloader.stop(timeout=15)
 
 
-@pytest.fixture(scope="session", autouse=not PYTEST_PLUGIN_MODE)
-def guard_invariant_on_v2_modules_in_data_dir(modules_v2_dir: str) -> None:
-    """
-    When the test suite runs, the python environment used to build V2 modules is cached using the IsolatedEnvBuilderCached
-    class. This cache relies on the fact that all modules in the tests/data/modules_v2 directory use the same build-backand
-    and build requirements. This guard verifies whether that assumption is fulfilled and raises an exception if it's not.
-    """
-    for dir_name in os.listdir(modules_v2_dir):
-        module_path = os.path.join(modules_v2_dir, dir_name)
-        pyproject_toml_path = os.path.join(module_path, "pyproject.toml")
-        error_message = f"""
-Module {module_path} has a pyproject.toml file that is incompatible with the requirements of this test suite.
-The build-backend and the build requirements should be set as follows:
-
-[build-system]
-requires = ["setuptools", "wheel"]
-build-backend = "setuptools.build_meta"
-
-All modules present in the tests/data/module_v2 directory should satisfy the above-mentioned requirements, because
-the test suite caches the python environment used to build the V2 modules. This cache relies on the assumption that all modules
-use the same build-backend and build requirements.
-        """.strip()
-        with open(pyproject_toml_path, "r", encoding="utf-8") as fh:
-            pyproject_toml_as_dct = toml.load(fh)
-            try:
-                if pyproject_toml_as_dct["build-system"]["build-backend"] != "setuptools.build_meta" or set(
-                    pyproject_toml_as_dct["build-system"]["requires"]
-                ) != {"setuptools", "wheel"}:
-                    raise Exception(error_message)
-            except (KeyError, TypeError):
-                raise Exception(error_message)
-
-
 @pytest.fixture(scope="session", autouse=not PYTEST_PLUGIN_MODE)
 def guard_testing_venv():
     """
@@ -1730,32 +1600,3 @@ async def set_running_tests():
     Ensure the RUNNING_TESTS variable is True when running tests
     """
     inmanta.RUNNING_TESTS = True
-
-
-@pytest.fixture(scope="session")
-def index_with_pkgs_containing_optional_deps() -> str:
-    """
-    This fixture creates a python package repository containing packages with optional dependencies.
-    These packages are NOT inmanta modules but regular python packages. This fixture returns the URL
-    to the created python package repository.
-    """
-    with tempfile.TemporaryDirectory() as tmpdirname:
-        pip_index = utils.PipIndex(artifact_dir=tmpdirname)
-        utils.create_python_package(
-            name="pkg",
-            pkg_version=Version("1.0.0"),
-            path=os.path.join(tmpdirname, "pkg"),
-            publish_index=pip_index,
-            optional_dependencies={
-                "optional-a": [Requirement.parse("dep-a")],
-                "optional-b": [Requirement.parse("dep-b"), Requirement.parse("dep-c")],
-            },
-        )
-        for pkg_name in ["dep-a", "dep-b", "dep-c"]:
-            utils.create_python_package(
-                name=pkg_name,
-                pkg_version=Version("1.0.0"),
-                path=os.path.join(tmpdirname, pkg_name),
-                publish_index=pip_index,
-            )
-        yield pip_index.url
