@@ -18,14 +18,15 @@
 import asyncio
 import configparser
 import datetime
+import inspect
 import json
 import logging
 import os
 import shutil
+import time
 import uuid
-from collections import abc
 from dataclasses import dataclass
-from typing import Any, Dict, Optional, Sequence, Type, TypeVar, Union
+from typing import Any, Dict, Optional, Sequence, Union
 
 import pytest
 import yaml
@@ -35,7 +36,7 @@ from pydantic.tools import lru_cache
 import build
 import build.env
 from _pytest.mark import MarkDecorator
-from inmanta import const, data, env, module, util
+from inmanta import const, data, env, module
 from inmanta.moduletool import ModuleTool
 from inmanta.protocol import Client
 from inmanta.server.bootloader import InmantaBootloader
@@ -44,26 +45,18 @@ from inmanta.util import get_compiler_version
 from libpip2pi.commands import dir2pi
 from packaging import version
 
-T = TypeVar("T")
 
+async def retry_limited(fun, timeout, *args, **kwargs):
+    async def fun_wrapper():
+        if inspect.iscoroutinefunction(fun):
+            return await fun(*args, **kwargs)
+        else:
+            return fun(*args, **kwargs)
 
-def get_all_subclasses(cls: Type[T]) -> set[Type[T]]:
-    """
-    Returns all loaded subclasses of any depth for a given class. Includes the class itself.
-    """
-    return {cls}.union(*(get_all_subclasses(sub) for sub in cls.__subclasses__()))
-
-
-async def retry_limited(
-    fun: Union[abc.Callable[..., bool], abc.Callable[..., abc.Awaitable[bool]]],
-    timeout: float,
-    interval: float = 0.1,
-    *args: object,
-    **kwargs: object,
-) -> None:
-    try:
-        await util.retry_limited(fun, timeout, interval, *args, **kwargs)
-    except asyncio.TimeoutError:
+    start = time.time()
+    while time.time() - start < timeout and not (await fun_wrapper()):
+        await asyncio.sleep(0.1)
+    if not (await fun_wrapper()):
         raise AssertionError("Bounded wait failed")
 
 
@@ -225,20 +218,6 @@ class LogSequence(object):
         self.assert_not("", logging.ERROR, "")
 
 
-NOISY_LOGGERS = [
-    "inmanta.config",  # Option deprecations
-    "inmanta.util",  # cancel background tasks
-]
-
-
-def assert_no_warning(caplog, loggers_to_allow: list[str] = NOISY_LOGGERS):
-    """
-    Assert there are no warning, except from the list of loggers to allow
-    """
-    for record in caplog.records:
-        assert record.levelname != "WARNING" or (record.name in loggers_to_allow), record
-
-
 def configure(unused_tcp_port, database_name, database_port):
     import inmanta.agent.config  # noqa: F401
     import inmanta.server.config  # noqa: F401
@@ -383,7 +362,6 @@ def create_python_package(
     install: bool = False,
     editable: bool = False,
     publish_index: Optional[PipIndex] = None,
-    optional_dependencies: Optional[Dict[str, Sequence[Requirement]]] = None,
 ) -> None:
     """
     Creates an empty Python package.
@@ -413,8 +391,6 @@ build-backend = "setuptools.build_meta"
 requires = ["setuptools"]
             """.strip()
         )
-
-    install_requires_content = "".join(f"\n  {req}" for req in (requirements if requirements is not None else []))
     with open(os.path.join(path, "setup.cfg"), "w") as fd:
         egg_info: str = (
             f"""
@@ -435,18 +411,12 @@ author = Inmanta <code@inmanta.com>
 
 {egg_info}
 
-""".strip()
+[options]
+install_requires =%s
+            """.strip()
+            % "".join(f"\n  {req}" for req in (requirements if requirements is not None else []))
         )
 
-        fd.write("\n[options]")
-        fd.write(f"\ninstall_requires ={install_requires_content}")
-
-        if optional_dependencies:
-            fd.write("\n[options.extras_require]")
-            for option_name, requirements in optional_dependencies.items():
-                requirements_as_string = "".join(f"\n  {req}" for req in requirements)
-                fd.write(f"\n{option_name} ={requirements_as_string}")
-
     if install:
         env.process_env.install_from_source([env.LocalPackagePath(path=path, editable=editable)])
     if publish_index is not None:
@@ -467,7 +437,6 @@ def module_from_template(
     new_version: Optional[version.Version] = None,
     new_name: Optional[str] = None,
     new_requirements: Optional[Sequence[Union[module.InmantaModuleRequirement, Requirement]]] = None,
-    new_extras: Optional[abc.Mapping[str, abc.Sequence[Union[module.InmantaModuleRequirement, Requirement]]]] = None,
     install: bool = False,
     editable: bool = False,
     publish_index: Optional[PipIndex] = None,
@@ -483,7 +452,6 @@ def module_from_template(
     :param new_version: The new version for the module, if any.
     :param new_name: The new name of the inmanta module, if any.
     :param new_requirements: The new requirements for the module, if any.
-    :param new_extras: The new optional dependencies for the module, if any.
     :param install: Install the newly created module with the module tool. Requires virtualenv to be installed in the
         python environment unless editable is True.
     :param editable: Whether to install the module in editable mode, ignored if install is False.
@@ -492,12 +460,6 @@ def module_from_template(
     :param new_content_init_py: The new content of the __init__.py file.
     :param in_place: Modify the module in-place instead of copying it.
     """
-
-    def to_python_requires(
-        requires: abc.Sequence[Union[module.InmantaModuleRequirement, Requirement]]
-    ) -> abc.Iterator[Requirement]:
-        return (str(req if isinstance(req, Requirement) else req.get_python_package_requirement()) for req in requires)
-
     if (dest_dir is None) != in_place:
         raise ValueError("Either dest_dir or in_place must be set, never both.")
     if dest_dir is None:
@@ -508,10 +470,9 @@ def module_from_template(
     config: configparser.ConfigParser = configparser.ConfigParser()
     config.read(config_file)
     if new_version is not None:
-        base, tag = module.ModuleV2Metadata.split_version(new_version)
-        config["metadata"]["version"] = base
-        if tag is not None:
-            config["egg_info"] = {"tag_build": tag}
+        config["metadata"]["version"] = new_version.base_version
+        if new_version.is_devrelease:
+            config["egg_info"] = {"tag_build": f".dev{new_version.dev}"}
     if new_name is not None:
         old_name: str = module.ModuleV2Source.get_inmanta_module_name(config["metadata"]["name"])
         os.rename(
@@ -526,13 +487,10 @@ def module_from_template(
         with open(manifest_file, "w", encoding="utf-8") as fd:
             fd.write(manifest_content.replace(f"inmanta_plugins/{old_name}/", f"inmanta_plugins/{new_name}/"))
     if new_requirements:
-        config["options"]["install_requires"] = "\n    ".join(to_python_requires(new_requirements))
-    if new_extras:
-        # start from a clean slate
-        config.remove_section("options.extras_require")
-        config.add_section("options.extras_require")
-        for extra, requires in new_extras.items():
-            config["options.extras_require"][extra] = "\n    ".join(to_python_requires(requires))
+        config["options"]["install_requires"] = "\n    ".join(
+            str(req if isinstance(req, Requirement) else module.ModuleV2Source.get_python_package_requirement(req))
+            for req in new_requirements
+        )
     if new_content_init_cf is not None:
         init_cf_file = os.path.join(dest_dir, "model", "_init.cf")
         with open(init_cf_file, "w", encoding="utf-8") as fd:
@@ -603,7 +561,7 @@ def v1_module_from_template(
         with open(os.path.join(dest_dir, "requirements.txt"), "w") as fd:
             fd.write(
                 "\n".join(
-                    str(req if isinstance(req, Requirement) else req.get_python_package_requirement())
+                    str(req if isinstance(req, Requirement) else module.ModuleV2Source.get_python_package_requirement(req))
                     for req in new_requirements
                 )
             )
@@ -613,43 +571,3 @@ def v1_module_from_template(
 
 def parse_datetime_to_utc(time: str) -> datetime.datetime:
     return datetime.datetime.strptime(time, "%Y-%m-%dT%H:%M:%S.%f").replace(tzinfo=datetime.timezone.utc)
-
-
-async def resource_action_consistency_check():
-    """
-    The resourceaction table is joined to the resource table in two different ways
-    This method asserts that
-        - both methods produce identical results (i.e. the updates are consistent)
-        - both methods are in use (i.e. the queries return at least one record)
-    """
-
-    async def get_data(postgresql_client):
-        post_ra_one = await postgresql_client.fetch(
-            """SELECT ra.action_id, r.environment, r.resource_version_id FROM public.resourceaction as ra
-                    INNER JOIN public.resource as r
-                    ON r.resource_version_id = ANY(ra.resource_version_ids)
-                    AND r.environment = ra.environment
-            """
-        )
-        post_ra_one_set = {(r[0], r[1], r[2]) for r in post_ra_one}
-
-        post_ra_two = await postgresql_client.fetch(
-            """SELECT ra.action_id, r.environment, r.resource_version_id FROM public.resource as r
-                    INNER JOIN public.resourceaction_resource as jt
-                         ON r.environment = jt.environment
-                        AND r.resource_id = jt.resource_id
-                        AND r.model = jt.resource_version
-                    INNER JOIN public.resourceaction as ra
-                        ON ra.action_id = jt.resource_action_id
-            """
-        )
-        post_ra_two_set = {(r[0], r[1], r[2]) for r in post_ra_two}
-        return post_ra_one_set, post_ra_two_set
-
-    # The above-mentioned queries have to be executed with at least the repeatable_read isolation level.
-    # Otherwise it might happen that a repair run adds more resource actions between the execution of both queries.
-    (post_ra_one_set, post_ra_two_set) = await data.ResourceAction.execute_in_retryable_transaction(
-        get_data, tx_isolation_level="repeatable_read"
-    )
-    assert post_ra_one_set == post_ra_two_set
-    assert post_ra_one_set
